@@ -248,11 +248,14 @@ function [local_packages, global_packages] = pkg (varargin)
 	global_install = false;
 	if (! user_prefix)
 	  prefix = tilde_expand (fullfile ("~", "octave"));
+	  archprefix = prefix;
 	endif
       case "-global"
 	global_install = true;
 	if (! user_prefix)
 	  prefix = fullfile (OCTAVE_HOME (), "share", "octave", "packages");
+	  archprefix = fullfile (octave_config_info ("libexecdir"),
+				 "octave", "packages");
 	endif
       case available_actions
 	if (strcmp (action, "none"))
@@ -1299,7 +1302,7 @@ function configure_make (desc, packdir, verbose)
     if (isempty (filenames))
       idx = [];
     else
-      idx = cellfun (@(x) is_architecture_dependent (x), filenames);
+      idx = cellfun (@is_architecture_dependent, filenames);
     endif
     archdependent = filenames (idx);
     archindependent = filenames (!idx);
